( cd usr/lib64 ; rm -rf libfreetype.so.6 )
( cd usr/lib64 ; ln -sf libfreetype.so.6.3.16 libfreetype.so.6 )
( cd usr/lib64 ; rm -rf libfreetype.so )
( cd usr/lib64 ; ln -sf libfreetype.so.6.3.16 libfreetype.so )
( cd usr/include ; rm -rf freetype )
( cd usr/include ; ln -sf freetype2/freetype freetype )
